@@ -2,7 +2,7 @@ package Power::Outlet;
 use strict;
 use warnings;
 
-our $VERSION='0.12';
+our $VERSION='0.14';
 
 =head1 NAME
 
@@ -10,7 +10,16 @@ Power::Outlet - Control and query network attached power outlets
 
 =head1 SYNOPSIS
 
-Constructs a L<Power::Outlet::iBoot>
+Command Line
+
+  power-outlet iBoot    ON   host mylamp
+  power-outlet iBoot    OFF  host mylamp
+  power-outlet iBootBar ON   host mybar   outlet 1
+  power-outlet iBootBar OFF  host mybar   outlet 1
+  power-outlet WeMo     ON   host mywemo
+  power-outlet WeMo     OFF  host mywemo
+
+Perl Object API
 
   my $outlet=Power::Outlet->new(                   #sane defaults from manufactures spec
                                 type => "iBoot",
@@ -20,19 +29,8 @@ Constructs a L<Power::Outlet::iBoot>
   print $outlet->on, "\n";
   print $outlet->off, "\n";
 
-Constructs a L<Power::Outlet::iBootBar>
-
-  my $outlet=Power::Outlet->new(       #sane defaults from manufactures spec
-                                type   => "iBootBar",
-                                host   => "mybar",
-                                outlet => 1,
-                               );
-  print $outlet->query, "\n";
-  print $outlet->on, "\n";
-  print $outlet->off, "\n";
-
 =head1 DESCRIPTION
- 
+
 Power::Outlet is a package for controlling and querying network attached power outlets.  Individual hardware drivers in this name space must provide a common object interface for the controlling and querying of an outlet.  Common methods that every network attached power outlet must know are on, off, query, switch and cycle.  Optional methods might be implemented in some drivers like amps and volts.
 
 =head2 SCOPE
@@ -41,7 +39,7 @@ The current scope of these packages is network attached power outlets. I have st
 
 =head2 FUTURE
 
-I hope to be able to support WeMo.  As well as integrate with services like IFTTT (ifttt.com).  I would appreciate community support to help develop drivers for USB controlled power strips and serial devices like the X10 family.
+I hope to integrate with services like IFTTT (ifttt.com).  I would appreciate community support to help develop drivers for USB controlled power strips and serial devices like the X10 family.
 
 =head1 USAGE
 
@@ -49,16 +47,17 @@ The Perl one liner
 
   perl -MPower::Outlet -e 'print Power::Outlet->new(type=>"iBoot", host=>shift)->switch, "\n"' lamp
 
-The included script
+The included command line script
 
-  power-outlet iBoot SWITCH host lamp
+  power-outlet iBoot ON host lamp
 
 =head1 CONSTRUCTOR
 
 =head2 new
 
-  my $outlet=Power::Outlet->new(type=>"iBoot", host=>"mylamp");
+  my $outlet=Power::Outlet->new(type=>"iBoot",    host=>"mylamp");
   my $outlet=Power::Outlet->new(type=>"iBootBar", host=>"mybar", outlet=>1);
+  my $outlet=Power::Outlet->new(type=>"WeMo",     host=>"mywemo");
 
 =cut
 
